@@ -4,6 +4,8 @@ from enum import Enum
 class BuildTypeEnum(str, Enum):
     BREW = "BREW"
     KOJI = "KOJI"
+    CENTOS = "CENTOS"
+    APP_INTERFACE = "APP_INTERFACE"
     # This is a temporary tweak to accept empty Enum
     NONE = ""
 
