@@ -3,13 +3,13 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 import attr
 
 from ..models.product import Product
-from ..types import UNSET, Unset
+from ..types import UNSET, ComponentRegistryModel, Unset
 
 T = TypeVar("T", bound="PaginatedProductList")
 
 
 @attr.s(auto_attribs=True)
-class PaginatedProductList:
+class PaginatedProductList(ComponentRegistryModel):
     """ """
 
     count: Union[Unset, int] = UNSET
