@@ -2,11 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
+from ..types import ComponentRegistryModel
+
 T = TypeVar("T", bound="V1SchemaRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class V1SchemaRetrieveResponse200:
+class V1SchemaRetrieveResponse200(ComponentRegistryModel):
     """ """
 
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
